<?php
/*
Plugin Name: BalesOtomatis.id
Plugin URI: https://balesotomatis.id/
Description: Plugin Resmi BalesOtomatis.id untuk terintegrasi dengan berbagai plugin lain seperti WooCommerce.
Version: 1.50
Author: Bales Otomatis Indonesia
Author URI: https://balesotomatis.id
License: GPL2
*/

function balesoto_wpplug_write_log($message) {
    // Tentukan lokasi file log
    $log_file = WP_CONTENT_DIR . '/uploads/balesotomatis.log';

    // Format pesan log
    $formatted_message = date('Y-m-d H:i:s') . " - " . $message . PHP_EOL;

    // Tulis pesan ke file log
    file_put_contents($log_file, $formatted_message, FILE_APPEND | LOCK_EX);
}

function balesoto_wpplug_getwooorders($order_id) {
    if (!$order_id) return;

    // Mendapatkan detail order
    $order = wc_get_order($order_id);

    // Informasi Penagihan (Billing)
    $billing_info = array(
        'first_name' => $order->get_billing_first_name(),
        'last_name' => $order->get_billing_last_name(),
        'email' => $order->get_billing_email(),
        'phone' => $order->get_billing_phone(),
        'address_1' => $order->get_billing_address_1(),
        'address_2' => $order->get_billing_address_2(),
        'city' => $order->get_billing_city(),
        'state' => $order->get_billing_state(),
        'postcode' => $order->get_billing_postcode(),
        'country' => $order->get_billing_country()
    );

    // Informasi Pengiriman (Shipping)
    $shipping_info = array(
        'first_name' => $order->get_shipping_first_name(),
        'last_name' => $order->get_shipping_last_name(),
        'address_1' => $order->get_shipping_address_1(),
        'address_2' => $order->get_shipping_address_2(),
        'city' => $order->get_shipping_city(),
        'state' => $order->get_shipping_state(),
        'postcode' => $order->get_shipping_postcode(),
        'country' => $order->get_shipping_country()
    );

    // Informasi Produk yang Dibeli
    $list_products = array();

    $items = $order->get_items();
    foreach ($items as $item_id => $item) {
        $product_data = array(
            'product_name' => $item->get_name(),
            'product_quantity' => $item->get_quantity(),
            'product_tax_status' => $item->get_tax_status()
        );

        if ($item instanceof WC_Order_Item_Product) {
            $product = $item->get_product(); // Mendapatkan objek produk

            if ($product && $product->is_type('variation')) {
                $product_data['product_variation_id'] = $product->get_id();
                $product_data['variation_attributes'] = $product->get_attributes();
            }
        }

        $list_products[] = $product_data;
    }

    // Informasi Pembayaran
    $payment_info = array(
        'method' => $order->get_payment_method(),
        'method_title' => $order->get_payment_method_title(),
        'total' => $order->get_total(),
        'status' => $order->get_status()
    );

    // Informasi Tambahan
    $additional_info = array(
        'order_id' => $order->get_id(),
        'order_date' => $order->get_date_created()->date('Y-m-d H:i:s'),
        'customer_note' => $order->get_customer_note()
    );

    // Gabungkan semua informasi menjadi satu array
    $order_data = array(
        'billing_info' => $billing_info,
        'shipping_info' => $shipping_info,
        'products' => $list_products,
        'payment_info' => $payment_info,
        'additional_info' => $additional_info
    );

    return $order_data;
}

function balesoto_ReplacePlaceholders($str, $replacer) {
    // Loop melalui array replacer untuk menggantikan placeholder
    foreach ($replacer as $key => $value) {
        // Placeholder ditandai dengan {{key}}
        $placeholder = $key;
        // Ganti placeholder dengan nilai di array
        $str = str_replace($placeholder, $value, $str);
    }
    return $str;
}

function balesoto_send_followup_wa($order_id, $template_name){
    if (!$order_id) return;

    // Mendapatkan detail order
    $order = balesoto_wpplug_getwooorders($order_id);
    $template_wa_message = get_option($template_name, '');
    $whatsapp_devices_selected = get_option('balesoto-sending-number-key', 'all');

    if(!empty($template_wa_message)){
        $replacer = [
            "{{billing_first_name}}" => $order['billing_info']['first_name'],
            "{{billing_last_name}}" => $order['billing_info']['last_name'],
            "{{billing_email}}" => $order['billing_info']['email'],
            "{{billing_phone}}" => $order['billing_info']['phone'],
            "{{billing_address_1}}" => $order['billing_info']['address_1'],
            "{{billing_address_2}}" => $order['billing_info']['address_2'],
            "{{billing_city}}" => $order['billing_info']['city'],
            "{{billing_state}}" => $order['billing_info']['state'],
            "{{billing_postcode}}" => $order['billing_info']['postcode'],
            "{{billing_country}}" => $order['billing_info']['country'],
            "{{shipping_first_name}}" => $order['shipping_info']['first_name'],
            "{{shipping_last_name}}" => $order['shipping_info']['last_name'],
            "{{shipping_address_1}}" => $order['shipping_info']['address_1'],
            "{{shipping_address_2}}" => $order['shipping_info']['address_2'],
            "{{shipping_city}}" => $order['shipping_info']['city'],
            "{{shipping_state}}" => $order['shipping_info']['state'],
            "{{shipping_postcode}}" => $order['shipping_info']['postcode'],
            "{{shipping_country}}" => $order['shipping_info']['country'],
            "{{payment_method}}" => $order['payment_info']['method_title'],
            "{{order_total}}" => $order['payment_info']['total'],
            "{{order_status}}" => $order['payment_info']['status']
        ];
        
        // Jika ingin menambahkan produk ke dalam placeholder
        $products_name = Array();
        $products_qty = Array();

        if (!empty($order['products'])) {
            foreach ($order['products'] as $index => $product) {
                $products_name[] = $product['product_name'];
                $products_qty[] = $product['product_quantity'].' pcs';

                // $replacer["{{product_name_{$index}}}"] = $product['product_name'];
                // $replacer["{{product_quantity_{$index}}}"] = $product['product_quantity'];
            }
        }

        $replacer["{{product_name}}"] = implode(", ",$products_name);
        $replacer["{{product_quantity}}"] = implode(", ",$products_qty);

        $template_wa_message = balesoto_ReplacePlaceholders($template_wa_message, $replacer);
        if(!empty($whatsapp_devices_selected)){
            $balesoto_api_key = get_option('balesoto_api_key', '');
            if(!empty($balesoto_api_key)){
                send_personal_message_balesotomatis($balesoto_api_key, $whatsapp_devices_selected, $order['billing_info']['phone'], $template_wa_message, '62');
            }
        }
    }
}
add_action('woocommerce_thankyou', 'balesoto_wpplug_after_purchase', 10, 1);

function balesoto_wpplug_after_purchase($order_id) {
    balesoto_send_followup_wa($order_id, 'on-hold-template');
}

function balesoto_wpplug_on_order_status_change($order_id, $old_status, $new_status) {
    // Contoh: Kirim notifikasi jika status berubah menjadi "completed"
    // $tabs = ['pending-payment', 'on-hold', 'processing', 'completed', 'cancelled', 'refunded'];

    if ($new_status === 'completed') {
        balesoto_send_followup_wa($order_id, 'completed-template');
    }else if ($new_status === 'processing') {
        balesoto_send_followup_wa($order_id, 'processing-template');
    }else if ($new_status === 'cancelled') {
        balesoto_send_followup_wa($order_id, 'cancelled-template');
    }else if ($new_status === 'refunded') {
        balesoto_send_followup_wa($order_id, 'refunded-template');
    }
}
add_action('woocommerce_order_status_changed', 'balesoto_wpplug_on_order_status_change', 10, 3);


function balesoto_wpplug_add_admin_menu() {
    add_menu_page(
        'WooCommerce x BalesOtomatis.id - Plugin Settings',
        'BalesOtomatis.id',
        'manage_options',
        'balesoto-wp-settings',
        'balesoto_wpplug_settings_page'
    );
}
add_action('admin_menu', 'balesoto_wpplug_add_admin_menu');

function balesoto_save_template() {
    // Cek nonce untuk validasi keamanan
    if (!isset($_POST['_wpnonce']) || !wp_verify_nonce($_POST['_wpnonce'], 'balesoto_save_template_nonce')) {
        wp_send_json_error(['message' => 'Nonce validation failed']);
    }

    // Menyimpan template ke database (misalnya menggunakan opsi atau custom post type)
    foreach ($_POST as $key => $value) {
        if($key == 'balesoto-sending-number-key'){
            update_option($key, sanitize_textarea_field($value));
        }else{
            if (strpos($key, '-template') !== false) {
                update_option($key, sanitize_textarea_field($value));
            }
        }
    }

    wp_send_json_success(['message' => 'Template saved successfully']);
}
add_action('wp_ajax_balesoto_save_template', 'balesoto_save_template');

// Hook untuk menangani AJAX request
add_action( 'wp_ajax_logout_integration_action', 'handle_logout_integration_action' );

function handle_logout_integration_action() {
    // Pastikan permintaan datang dari pengguna yang memiliki izin
    if( !current_user_can( 'manage_options' ) ) {
        wp_send_json_error( ['message' => 'Unauthorized'] );
    }

    // Hapus options yang diminta
    delete_option( 'balesoto-sending-number-key' );
    delete_option( 'balesoto_api_key' );

    delete_option( 'pending-payment-template' );
    delete_option( 'on-hold-template' );
    delete_option( 'completed-template' );
    delete_option( 'processing-template' );
    delete_option( 'cancelled-template' );
    delete_option( 'refunded-template' );

    // Kirimkan response sukses
    wp_send_json_success();
}

function send_personal_message_balesotomatis($api_key, $number_id, $target_phone_no, $message, $country_code = '62') {
    // URL endpoint API BalesOtomatis.id
    $api_url = 'https://api.balesotomatis.id/public/v1/send_personal_message';

    // Data untuk dikirimkan dalam permintaan POST
    $payload = array(
        'api_key' => $api_key,
        'number_id' => $number_id,
        'enable_typing' => '1',
        'method_send' => 'async',
        'phone_no' => $target_phone_no,
        'country_code' => $country_code,
        'message' => $message
    );

    // Konfigurasi cURL
    $args = array(
        'body' => json_encode($payload),
        'headers' => array(
            'Content-Type' => 'application/json'
        ),
        'method' => 'POST',
        'timeout' => 10
    );

    // Kirim permintaan menggunakan wp_remote_post
    $response = wp_remote_post($api_url, $args);

    // Periksa apakah ada kesalahan
    if (is_wp_error($response)) {
        return array(
            'success' => false,
            'error' => $response->get_error_message()
        );
    }

    // Decode respons
    $response_body = wp_remote_retrieve_body($response);
    return json_decode($response_body, true);
}

function get_info_balesotomatis($api_key) {
    // URL endpoint API BalesOtomatis.id
    $api_url = 'https://api.balesotomatis.id/public/v1/info';

    // Data untuk dikirimkan dalam permintaan POST
    $payload = array(
        'api_key' => $api_key
    );

    // Konfigurasi cURL menggunakan wp_remote_post
    $args = array(
        'body' => json_encode($payload),
        'headers' => array(
            'Content-Type' => 'application/json'
        ),
        'method' => 'POST',
        'timeout' => 10
    );

    // Kirim permintaan menggunakan wp_remote_post
    $response = wp_remote_post($api_url, $args);

    // Periksa apakah ada kesalahan
    if (is_wp_error($response)) {
        return array(
            'success' => false,
            'error' => $response->get_error_message()
        );
    }

    // Decode respons
    $response_body = wp_remote_retrieve_body($response);
    return json_decode($response_body, true);
}

function balesoto_is_active_until_valid($active_until) {
    // Konversi tanggal active_until ke timestamp
    $active_until_timestamp = strtotime($active_until);

    // Dapatkan timestamp saat ini
    $current_timestamp = time();

    // Periksa apakah active_until lebih besar dari timestamp saat ini
    return $active_until_timestamp > $current_timestamp;
}

// Menangani login via AJAX
function process_login() {
    $email = isset($_POST['email']) ? sanitize_email($_POST['email']) : '';
    $api_key = isset($_POST['api_key']) ? sanitize_text_field($_POST['api_key']) : '';

    if (empty($email) || empty($api_key)) {
        wp_send_json_error(['message' => 'Email dan API key wajib diisi.']);
    }

    $info_balesoto = get_info_balesotomatis($api_key);
    if($info_balesoto['code'] == '200'){
        $info_balesoto_data_info = $info_balesoto['info'];
        $info_balesoto_data_user = $info_balesoto_data_info['user'];

        if($info_balesoto_data_user['email'] = $email){
            if(!empty($info_balesoto_data_info)){
                $package = strtolower($info_balesoto_data_info['package']['name']);
    
                if(($package == 'enterprise') || ($package == 'pro')){
                    $is_active = balesoto_is_active_until_valid($info_balesoto_data_info['package']['active_until']);
    
                    if($is_active){
                        update_option('balesoto_api_key', sanitize_text_field($api_key));
                        wp_send_json_error(['success' => true, 'message' => 'Successfully Connected']);
                    }else{
                        wp_send_json_error(['success' => false, 'message' => 'Your Subscription Now Expired']);
                    }
                }else{
                    wp_send_json_error(['success' => false, 'message' => 'Your Subscription Package Not Supported']); 
                }
            }else{
                wp_send_json_error(['success' => false, 'message' => 'Invalid Email / API Key']); 
            }
        }else{
            wp_send_json_error(['success' => false, 'message' => 'Invalid Email / API Key']); 
        }
        
    }else{
        wp_send_json_error(['success' => false, 'message' => 'Something Went Wrong, Make Sure You Have Internet Connection']); 
    }
}
add_action('wp_ajax_process_login', 'process_login');
add_action('wp_ajax_nopriv_process_login', 'process_login');

// Halaman pengaturan
function balesoto_wpplug_settings_page() {

    $balesoto_api_key = get_option('balesoto_api_key', '');

    if(empty($balesoto_api_key)){
       ?>
        <div class="wrap">
            <h1>BalesOtomatis.id Integrations</h1>
            <div class="balesoto-inner-wrap">
                <form name="balesoto-integrate-wp" class="modern-login-form" id="balesoto-integrate-wp">
                    <div class="error-message" id="error-message"></div>
                    <input type="email" id="email" name="email" placeholder="Email BalesOtomatis.id Account" required />
                    <input type="text" id="api_key" name="api_key" placeholder="API Key" required />
                    <button type="submit">Integrate Now</button>
                </form>
            </div>
        </div>
        <!-- SweetAlert2 CDN -->
        <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
        <script>
            document.getElementById('balesoto-integrate-wp').addEventListener('submit', async function (e) {
                e.preventDefault();
                const errorMessage = document.getElementById('error-message');
                const email = document.getElementById('email').value;
                const apiKey = document.getElementById('api_key').value;

                if (!email || !apiKey) {
                    errorMessage.textContent = 'Semua field wajib diisi.';
                    return;
                }

                errorMessage.textContent = '';
                
                const response = await fetch('<?php echo admin_url('admin-ajax.php'); ?>', {
                    method: 'POST',
                    headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
                    body: new URLSearchParams({
                        action: 'process_login',
                        email: email,
                        api_key: apiKey
                    })
                });

                const result = await response.json();
                if (result?.data?.success) {
                    // alert('Login berhasil!');
                    Swal.fire({
                        title: 'Success!',
                        text: 'Connection Successfully!',
                        icon: 'success',
                        confirmButtonText: 'OK'
                    }).then((okeres) => {
                        location?.reload();
                    })
                } else {
                    errorMessage.textContent = result?.data?.message;
                }
            });
        </script>
       <?php
    }else{
        $info_balesoto = get_info_balesotomatis($balesoto_api_key);
        if($info_balesoto['code'] == '200'){
            $info_balesoto_data_info = $info_balesoto['info'];
            if(!empty($info_balesoto_data_info)){
                $package = strtolower($info_balesoto_data_info['package']['name']);

                if(($package == 'enterprise') || ($package == 'pro')){
                    $is_active = balesoto_is_active_until_valid($info_balesoto_data_info['package']['active_until']);

                    if($is_active){

                        if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
                        // Variabel pilihan yang tersedia
                        $variables = [
                            "{{billing_first_name}}" => "Billing First Name",
                            "{{billing_last_name}}" => "Billing Last Name",
                            "{{billing_email}}" => "Billing Email",
                            "{{billing_phone}}" => "Billing Phone",
                            "{{billing_address_1}}" => "Billing Address 1",
                            "{{billing_address_2}}" => "Billing Address 2",
                            "{{billing_city}}" => "Billing City",
                            "{{billing_state}}" => "Billing State",
                            "{{billing_postcode}}" => "Billing Postcode",
                            "{{billing_country}}" => "Billing Country",
                            "{{product_name}}" => "Product Name",
                            "{{product_quantity}}" => "Quantity",
                            "{{shipping_first_name}}" => "Shipping First Name",
                            "{{shipping_last_name}}" => "Shipping Last Name",
                            "{{shipping_address_1}}" => "Shipping Address 1",
                            "{{shipping_address_2}}" => "Shipping Address 2",
                            "{{shipping_city}}" => "Shipping City",
                            "{{shipping_state}}" => "Shipping State",
                            "{{shipping_postcode}}" => "Shipping Postcode",
                            "{{shipping_country}}" => "Shipping Country",
                            "{{payment_method}}" => "Payment Method",
                            "{{order_total}}" => "Order Total",
                            "{{order_status}}" => "Order Status"
                        ];

                        $whatsapp_devices = $info_balesoto_data_info['devices'];

                        $whatsapp_devices_selected = get_option('balesoto-sending-number-key', 'all')

                        ?>
                        <div class="wrap">
                            <h1>BalesOtomatis.id Integrations</h1>

                            <div class="balesoto-inner-wrap">
                                <h2>WooCommerce - Notification Settings | <a href="javascript:;" onclick="LogOutIntegration()">Log Out</a></h2>
                                    <div class="tabs">
                                        <div class="tab active" data-tab="pending-payment">Pending Payment</div>
                                        <div class="tab" data-tab="on-hold">On Hold</div>
                                        <div class="tab" data-tab="processing">Processing</div>
                                        <div class="tab" data-tab="completed">Completed</div>
                                        <div class="tab" data-tab="cancelled">Cancelled</div>
                                        <div class="tab" data-tab="refunded">Refunded</div>
                                    </div>

                                    <form id="balesoto-settings-form" method="POST" action="">
                                        <?php wp_nonce_field('balesoto_save_template_nonce'); ?>
                                        <?php
                                        $tabs = ['pending-payment', 'on-hold', 'processing', 'completed', 'cancelled', 'refunded'];
                                        foreach ($tabs as $tab) {
                                        ?>
                                            <div id="<?= $tab ?>" class="balesoto-settings-form-frame tab-content <?= $tab === 'pending-payment' ? 'active' : '' ?>">
                                                <div class="toolbar">
                                                    <a href="javascript:;" class="toolbar-item" id="bold-<?= $tab ?>" onclick="ApplyFormatting(this)" data-tag="bold">B</a>
                                                    <a href="javascript:;" class="toolbar-item" id="italic-<?= $tab ?>" onclick="ApplyFormatting(this)" data-tag="italic">I</a>
                                                    <a href="javascript:;" class="toolbar-item" id="strikethrough-<?= $tab ?>" onclick="ApplyFormatting(this)" data-tag="strikethrough">S</a>

                                                    <div class="parent-variable">
                                                        <select name="variable-woo-commerce" class="toolbar-select">
                                                            <option value="">-- Choose Variable --</option>
                                                            <?php
                                                            foreach ($variables as $key => $value) {
                                                                echo "<option value=\"$key\">$value</option>";
                                                            }
                                                            ?>
                                                        </select>
                                                        <a href="javascript:;" class="toolbar-item" data-tab="<?= $tab ?>" onclick="InsertVariablesIntoTextarea(this)">Insert</a>
                                                    </div>
                                                </div>
                                                <textarea name="<?= $tab ?>-template" class="<?= $tab ?>-template" rows="5"><?php echo get_option($tab.'-template', ''); ?></textarea>
                                            </div>
                                        <?php
                                        }
                                        ?>
                                        <div class="frame-submit-balesoto-template">
                                            <div class="frame-selector-sender-balesoto">
                                                <label>Sending From</label>
                                                <select name="balesoto-sending-number-key" class="balesoto-sending-number-key">
                                                    <option <?php echo (($whatsapp_devices_selected == 'all') ? 'selected="selected"' : '') ?> value="all">All Numbers</option>
                                                    <?php
                                                    if(!empty($whatsapp_devices)){
                                                        foreach ($whatsapp_devices as $key => $value) {
                                                            if(empty($value['number_whatsapp'])){
                                                                continue;
                                                            }
                                                            ?>
                                                            <option <?php echo (($whatsapp_devices_selected == $value['number_id']) ? 'selected="selected"' : '') ?> value="<?php echo $value['number_id']; ?>"><?php echo $value['number_whatsapp']; ?></option>
                                                            <?php
                                                        }
                                                    }
                                                    ?>
                                                </select>
                                            </div>
                                            <button type="submit" id="save-template-btn" class="button button-primary">Save Configuration</button>
                                            <div id="save-loader" style="display: none;">Saving...</div>
                                        </div>
                                    </form>
                            </div>
                            </div>

                            <!-- SweetAlert2 CDN -->
                            <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>

                            <script>
                                // Fungsi untuk mengubah tab yang aktif
                                document.querySelectorAll('.tab').forEach(tab => {
                                    tab.addEventListener('click', function() {
                                        const targetTab = this.getAttribute('data-tab');
                                        document.querySelectorAll('.tab').forEach(t => t.classList.remove('active'));
                                        document.querySelectorAll('.tab-content').forEach(t => t.classList.remove('active'));
                                        this.classList.add('active');
                                        document.getElementById(targetTab).classList.add('active');
                                    });
                                });

                                function LogOutIntegration() {
                                    Swal.fire({
                                        title: 'Are you sure you want to log out?',
                                        text: "This action may prevent order notifications from being sent on this website.",
                                        icon: 'warning',
                                        showCancelButton: true,
                                        confirmButtonText: 'Yes, log out',
                                        cancelButtonText: 'Cancel',
                                        reverseButtons: true
                                    }).then((result) => {
                                        if (result.isConfirmed) {
                                            // Lakukan AJAX dengan fetch
                                            fetch(ajaxurl, {
                                                method: 'POST',
                                                headers: {
                                                    'Content-Type': 'application/x-www-form-urlencoded'
                                                },
                                                body: new URLSearchParams({
                                                    action: 'logout_integration_action'
                                                })
                                            })
                                            .then(response => response.json())
                                            .then(data => {
                                                if (data.success) {
                                                    Swal.fire(
                                                        'Logged out!',
                                                        'You have been logged out successfully.',
                                                        'success'
                                                    ).then((res) => {
                                                        location?.reload()
                                                    })
                                                } else {
                                                    Swal.fire(
                                                        'Error!',
                                                        'There was an issue while logging out.',
                                                        'error'
                                                    ).then((res) => {
                                                        location?.reload()
                                                    });
                                                }
                                            })
                                            .catch(error => {
                                                console.error('Error during AJAX request:', error);
                                                Swal.fire(
                                                    'Error!',
                                                    'An error occurred while processing your request.',
                                                    'error'
                                                ).then((res) => {
                                                    location?.reload()
                                                });
                                            });
                                        }
                                    });
                                }

                                function InsertVariablesIntoTextarea(button) {
                                    const select = button.previousElementSibling;
                                    const variable = select.value;
                                    const tab = button.getAttribute('data-tab');
                                    const textarea = document.querySelector(`textarea[name="${tab}-template"]`);

                                    if (!textarea) return;

                                    const start = textarea.selectionStart;
                                    const end = textarea.selectionEnd;
                                    const selectedText = textarea.value.substring(start, end);

                                    let newText = selectedText ? `${selectedText}${variable}` : `${variable}`;
                                    textarea.setRangeText(newText, start, end, 'select');
                                }

                                function ApplyFormatting(button) {
                                    const tag = button.getAttribute('data-tag');
                                    var tab = button.id.split('-template')[0];
                                    tab = tab.split(tag + '-')[1];
                                    const textareaname = `${tab}-template`;
                                    const textarea = document.querySelector(`textarea[name="${textareaname}"]`);

                                    const start = textarea.selectionStart;
                                    const end = textarea.selectionEnd;
                                    const selectedText = textarea.value.substring(start, end);

                                    let formattedText;
                                    if (tag === 'bold') {
                                        formattedText = selectedText ? `*${selectedText}*` : '**';
                                    } else if (tag === 'italic') {
                                        formattedText = selectedText ? `_${selectedText}_` : '_';
                                    } else if (tag === 'strikethrough') {
                                        formattedText = selectedText ? `~${selectedText}~` : '~~';
                                    }

                                    if (selectedText) {
                                        textarea.setRangeText(formattedText, start, end, 'select');
                                    } else {
                                        textarea.setRangeText(formattedText, start, end, 'end');
                                    }
                                }

                                // AJAX form submission
                                document.getElementById('balesoto-settings-form').addEventListener('submit', function(event) {
                                    event.preventDefault();

                                    const data = new FormData(this);
                                    const saveButton = document.getElementById('save-template-btn');
                                    const loader = document.getElementById('save-loader');

                                    saveButton.disabled = true;
                                    loader.style.display = 'inline';

                                    // Pastikan menggunakan ajaxurl yang benar
                                    data.append('action', 'balesoto_save_template'); // Nama action untuk AJAX
                                    data.append('_wpnonce', '<?php echo wp_create_nonce('balesoto_save_template_nonce'); ?>'); // Nonce untuk validasi

                                    fetch(ajaxurl, {
                                        method: 'POST',
                                        body: data,
                                    })
                                    .then(response => response.json())
                                    .then(data => {
                                        if (data.success) {
                                            Swal.fire({
                                                title: 'Success!',
                                                text: 'Template Saved Successfully!',
                                                icon: 'success',
                                                confirmButtonText: 'OK'
                                            });
                                        } else {
                                            Swal.fire({
                                                title: 'Error!',
                                                text: 'Failed to save template!',
                                                icon: 'error',
                                                confirmButtonText: 'OK'
                                            });
                                        }
                                        saveButton.disabled = false;
                                        loader.style.display = 'none';
                                    })
                                    .catch(error => {
                                        console.error('Error:', error);
                                        saveButton.disabled = false;
                                        loader.style.display = 'none';

                                        Swal.fire({
                                            title: 'Error!',
                                            text: 'Error occurred while saving template!',
                                            icon: 'error',
                                            confirmButtonText: 'OK'
                                        });
                                    });
                                });
                            </script>

                        <?php
                        }else{
                            ?>
                            <div class="wrap">
                                <h1>BalesOtomatis.id Integrations</h1>
                                <div class="balesoto-inner-wrap">
                                    <div class="alert alert-danger" role="alert">
                                        <strong>Error!</strong> Please install and activate the WooCommerce plugin first.
                                    </div>
                                </div>
                            </div>
                            <?php
                        }

                    }else{
                        ?>
                        <div class="wrap">
                            <h1>BalesOtomatis.id Integrations</h1>
                            <div class="balesoto-inner-wrap">
                                <div class="alert alert-danger" role="alert">
                                    <strong>Error!</strong> Your Package Now Expired, Renewal Now
                                </div>
                            </div>
                        </div>
                        <?php
                    }
                }else{
                    ?>
                    <div class="wrap">
                        <h1>BalesOtomatis.id Integrations</h1>
                        <div class="balesoto-inner-wrap">
                            <div class="alert alert-danger" role="alert">
                                <strong>Error!</strong> Required Pro / Enterprise Package to Use This Plugin
                            </div>
                        </div>
                    </div>
                    <?php
                }
            }else{
                ?>
                <div class="wrap">
                    <h1>BalesOtomatis.id Integrations</h1>
                    <div class="balesoto-inner-wrap">
                        <div class="alert alert-danger" role="alert">
                            <strong>Error!</strong> Account Not Found, Uninstall This Plugin Then Login Again
                        </div>
                    </div>
                </div>
                <?php
            }
        }else{
            ?>
            <div class="wrap">
                <h1>BalesOtomatis.id Integrations</h1>
                <div class="balesoto-inner-wrap">
                    <div class="alert alert-danger" role="alert">
                        <strong>Error!</strong> Something went wrong—please try again.
                    </div>
                </div>
            </div>
            <?php
        }
    }
    ?>
    <style>
        .alert {
            padding: 15px;
            margin: 10px 0;
            border-radius: 5px;
            position: relative;
            font-family: Arial, sans-serif;
            font-size: 16px;
        }

        /* Success alert */
        .alert-success {
            background-color: #d4edda;
            color: #155724;
            border: 1px solid #c3e6cb;
        }

        /* Error alert */
        .alert-danger {
            background-color: #f8d7da;
            color: #721c24;
            border: 1px solid #f5c6cb;
        }

        /* Close button */
        .close-btn {
            position: absolute;
            top: 10px;
            right: 10px;
            background: none;
            border: none;
            font-size: 20px;
            color: inherit;
            cursor: pointer;
        }

        /* Close button hover effect */
        .close-btn:hover {
            color: #aaa;
        }
        .tabs { display: flex;
        margin-bottom: 10px;
        margin-top: 20px; }
            .tab { padding: 10px; cursor: pointer; margin-right: 5px; background-color: #f1f1f1; border-radius: 5px; transition: background-color 0.3s; }
            .tab.active { background-color: #0073aa; color: white; }
            .tab-content { display: none; margin-top: 20px; }
            .tab-content.active { display: block; }
            .toolbar { margin-bottom: 0px; display: flex; background: #e8e8e8; padding: 8px 10px; border-radius: 10px; gap: 10px; border: 1px solid #dcdcdc; }
            .toolbar-item { display: inline-block; padding: 5px 10px; cursor: pointer; background-color: #f1f1f1; border-radius: 5px; text-align: center; text-decoration: none; min-width: 10px; border: 1px solid #0273aa; }
            .toolbar-item:hover { background-color: #0073aa; color: white; }
            .toolbar-select { padding: 5px; border-radius: 5px; }
            textarea { width: 100%; height: 150px; margin-top: 10px; padding: 10px; border: 1px solid #ddd; border-radius: 10px; }
            .parent-variable{ display: flex; flex-direction: row; flex-wrap: nowrap; align-content: center; justify-content: flex-start; align-items: center; gap: 10px; }
            .balesoto-settings-form-frame{
                margin-bottom: 10px;
            }
            .frame-submit-balesoto-template{
                display: flex;
                gap: 10px;
                flex-direction: row;
                flex-wrap: nowrap;
                align-content: center;
                justify-content: flex-start;
                align-items: flex-end;
            }
            .frame-submit-balesoto-template .button-primary{
                background: #2271b1;
                border-color: #2271b1;
                color: #fff;
                text-decoration: none;
                text-shadow: none;
                border-radius: 5px;
                padding: 4px 15px;
                font-size: 14px;
            }
            .balesoto-inner-wrap{
                background: white;
                padding: 20px;
                border-radius: 5px;
                margin-top: 10px;
            }
            .balesoto-inner-wrap h2{
                margin: 0px;
            }
            .frame-selector-sender-balesoto{
                display: flex;
                flex-direction: column;
                flex-wrap: nowrap;
                align-content: flex-start;
                align-items: flex-start;
                gap: 5px;
            }
            .frame-selector-sender-balesoto label{

            }
            .frame-selector-sender-balesoto select{

            }
            .modern-login-form {
                max-width: 400px;
                margin: 50px auto;
                /* padding: 20px; */
                /* border: 1px solid #ccc; */
                border-radius: 10px;
                /* box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1); */
                background-color: #fff;
                display: flex
            ;
                flex-direction: column;
                flex-wrap: nowrap;
                align-content: center;
                justify-content: center;
                align-items: center;
                gap: 13px;
            }
            .modern-login-form input[type="email"],
            .modern-login-form input[type="text"],
            .modern-login-form button {
                width: 100%;
                padding: 10px;
                /* margin-bottom: 10px; */
                border: 1px solid #ccc;
                border-radius: 5px;
                font-size: 16px;
            }
            .modern-login-form button {
                background-color: #0073aa;
                color: #fff;
                cursor: pointer;
                font-size: 17px;
                padding: 16px;
            }
            .modern-login-form button:hover {
                background-color: #005a8c;
            }
            .error-message {
                color: red;
                font-size: 14px;
                margin-bottom: 10px;
            }
        </style>
    <?php
}

function display_orders_by_status($status) {
    // Mengambil pesanan berdasarkan status dari WooCommerce
    $args = array(
        'status' => $status,
        'limit' => 5, // Menampilkan 5 pesanan terakhir
    );
    $orders = wc_get_orders($args);
    
    if (!empty($orders)) {
        echo '<ul>';
        foreach ($orders as $order) {
            echo '<li>Order #' . $order->get_id() . ' - ' . $order->get_status() . '</li>';
        }
        echo '</ul>';
    } else {
        echo '<p>Tidak ada pesanan dengan status ' . ucfirst($status) . '.</p>';
    }
}

// Registrasi pengaturan
function balesoto_wpplug_register_settings() {
    register_setting('balesoto_wpplug_settings', 'balesoto_wpplug_option');
}
add_action('admin_init', 'balesoto_wpplug_register_settings');